@@ -35,7 +35,7 @@
 #include "simulation/solver/linearSystem.h"
 #include "simulation/solver/mixedSystem.h"
 #include "simulation/solver/delay.h"
-#include "simulation/simulation_info_xml.h"
+#include "simulation/simulation_info_json.h"
 #include "simulation/simulation_input_xml.h"
 
 /*
@@ -143,10 +143,18 @@ fmiComponent fmiInstantiateModel(fmiString instanceName, fmiString GUID, fmiCall
   }
   comp = (ModelInstance *)functions.allocateMemory(1, sizeof(ModelInstance));
   if (comp) {
+    comp->functions = functions;
+    comp->loggingOn = loggingOn;
+    comp->state = modelInstantiated;
     comp->instanceName = functions.allocateMemory(1 + strlen(instanceName), sizeof(char));
     comp->GUID = functions.allocateMemory(1 + strlen(GUID), sizeof(char));
     /* Cannot use functions.allocateMemory since the pointer might not be stored on the stack of the parent */
-    DATA* fmudata = (DATA *)GC_malloc_uncollectable(sizeof(DATA));
+    DATA* fmudata = (DATA *)functions.allocateMemory(1, sizeof(DATA));
+    MODEL_DATA* modelData = (MODEL_DATA *)functions.allocateMemory(1, sizeof(MODEL_DATA));
+    SIMULATION_INFO* simInfo = (SIMULATION_INFO *)functions.allocateMemory(1, sizeof(SIMULATION_INFO));
+    fmudata->modelData = modelData;
+    fmudata->simulationInfo = simInfo;
+
 
     threadData_t *threadData = (threadData_t *)functions.allocateMemory(1, sizeof(threadData_t));
     memset(threadData, 0, sizeof(threadData_t));
@@ -168,8 +176,6 @@ fmiComponent fmiInstantiateModel(fmiString instanceName, fmiString GUID, fmiCall
     functions.logger(NULL, instanceName, fmiError, "error", "fmiInstantiateModel: Out of memory.");
     return NULL;
   }
-  if (comp->loggingOn) comp->functions.logger(NULL, instanceName, fmiOK, "log",
-      "fmiInstantiateModel: GUID=%s", GUID);
   /* intialize modelData */
   fmu1_model_interface_setupDataStruc(comp->fmuData);
   useStream[LOG_STDOUT] = 1;
@@ -179,14 +185,11 @@ fmiComponent fmiInstantiateModel(fmiString instanceName, fmiString GUID, fmiCall
   setDefaultStartValues(comp);
   setAllVarsToStart(comp->fmuData);
   setAllParamsToStart(comp->fmuData);
-  read_input_xml(&(comp->fmuData->modelData), &(comp->fmuData->simulationInfo));
-  modelInfoInit(&(comp->fmuData->modelData.modelDataXml));
+  comp->fmuData->callback->read_input_fmu(comp->fmuData->modelData, comp->fmuData->simulationInfo);
+  modelInfoInit(&(comp->fmuData->modelData->modelDataXml));
 
   strcpy((char*)comp->instanceName, (const char*)instanceName);
   strcpy((char*)comp->GUID, (const char*)GUID);
-  comp->functions = functions;
-  comp->loggingOn = loggingOn;
-  comp->state = modelInstantiated;
 
   /* read input vars */
   //input_function(comp->fmuData);
@@ -225,6 +228,7 @@ void fmiFreeModelInstance(fmiComponent c)
   /* free instanceName & GUID */
   if (comp->instanceName) comp->functions.freeMemory((void*)comp->instanceName);
   if (comp->GUID) comp->functions.freeMemory((void*)comp->GUID);
+
   /* free comp */
   comp->functions.freeMemory(comp);
 }
@@ -355,9 +359,9 @@ fmiStatus fmiSetContinuousStates(fmiComponent c, const fmiReal x[], size_t nx)
     fmiValueReference vr = vrStates[i];
     if (comp->loggingOn) comp->functions.logger(c, comp->instanceName, fmiOK, "log",
         "fmiSetContinuousStates: #r%d#=%.16g", vr, x[i]);
-    assert(vr>=0 && vr<NUMBER_OF_REALS);
-    if (setReal(comp, vr, x[i]) != fmiOK) // to be implemented by the includer of this file
+    if (vr<0 || vr>=NUMBER_OF_REALS || setReal(comp, vr, x[i]) != fmiOK) { // to be implemented by the includer of this file
       return fmiError;
+    }
   }
 #endif
   return fmiOK;
@@ -572,11 +576,11 @@ fmiStatus fmiGetEventIndicators(fmiComponent c, fmiReal eventIndicators[], size_
 #if NUMBER_OF_EVENT_INDICATORS>0
     /* eval needed equations*/
     comp->fmuData->callback->function_ZeroCrossingsEquations(comp->fmuData, comp->threadData);
-    comp->fmuData->callback->function_ZeroCrossings(comp->fmuData, comp->threadData, comp->fmuData->simulationInfo.zeroCrossings);
+    comp->fmuData->callback->function_ZeroCrossings(comp->fmuData, comp->threadData, comp->fmuData->simulationInfo->zeroCrossings);
     for (i=0; i<ni; i++) {
       /* retVal = getEventIndicator(comp, i, eventIndicators[i]); // to be implemented by the includer of this file
        * getEventIndicator(comp, eventIndicators); // to be implemented by the includer of this file */
-      eventIndicators[i] = comp->fmuData->simulationInfo.zeroCrossings[i];
+      eventIndicators[i] = comp->fmuData->simulationInfo->zeroCrossings[i];
       if (comp->loggingOn){
         comp->functions.logger(c, comp->instanceName, fmiOK, "log",
             "fmiGetEventIndicators: z%d = %.16g", i, eventIndicators[i]);
@@ -693,32 +697,32 @@ fmiStatus fmiEventUpdate(fmiComponent c, fmiBoolean intermediateResults, fmiEven
     storePreValues(comp->fmuData);
 
     /* activate sample event */
-    for(i=0; i<comp->fmuData->modelData.nSamples; ++i)
+    for(i=0; i<comp->fmuData->modelData->nSamples; ++i)
     {
-      if(comp->fmuData->simulationInfo.nextSampleTimes[i] <= comp->fmuData->localData[0]->timeValue)
+      if(comp->fmuData->simulationInfo->nextSampleTimes[i] <= comp->fmuData->localData[0]->timeValue)
       {
-        comp->fmuData->simulationInfo.samples[i] = 1;
-        infoStreamPrint(LOG_EVENTS, 0, "[%ld] sample(%g, %g)", comp->fmuData->modelData.samplesInfo[i].index, comp->fmuData->modelData.samplesInfo[i].start, comp->fmuData->modelData.samplesInfo[i].interval);
+        comp->fmuData->simulationInfo->samples[i] = 1;
+        infoStreamPrint(LOG_EVENTS, 0, "[%ld] sample(%g, %g)", comp->fmuData->modelData->samplesInfo[i].index, comp->fmuData->modelData->samplesInfo[i].start, comp->fmuData->modelData->samplesInfo[i].interval);
       }
     }
 
     comp->fmuData->callback->functionDAE(comp->fmuData, threadData);
 
     /* deactivate sample events */
-    for(i=0; i<comp->fmuData->modelData.nSamples; ++i)
+    for(i=0; i<comp->fmuData->modelData->nSamples; ++i)
     {
-      if(comp->fmuData->simulationInfo.samples[i])
+      if(comp->fmuData->simulationInfo->samples[i])
       {
-        comp->fmuData->simulationInfo.samples[i] = 0;
-        comp->fmuData->simulationInfo.nextSampleTimes[i] += comp->fmuData->modelData.samplesInfo[i].interval;
+        comp->fmuData->simulationInfo->samples[i] = 0;
+        comp->fmuData->simulationInfo->nextSampleTimes[i] += comp->fmuData->modelData->samplesInfo[i].interval;
       }
     }
 
-    for(i=0; i<comp->fmuData->modelData.nSamples; ++i)
-      if((i == 0) || (comp->fmuData->simulationInfo.nextSampleTimes[i] < comp->fmuData->simulationInfo.nextSampleEvent))
-        comp->fmuData->simulationInfo.nextSampleEvent = comp->fmuData->simulationInfo.nextSampleTimes[i];
+    for(i=0; i<comp->fmuData->modelData->nSamples; ++i)
+      if((i == 0) || (comp->fmuData->simulationInfo->nextSampleTimes[i] < comp->fmuData->simulationInfo->nextSampleEvent))
+        comp->fmuData->simulationInfo->nextSampleEvent = comp->fmuData->simulationInfo->nextSampleTimes[i];
 
-    if(comp->fmuData->callback->checkForDiscreteChanges(comp->fmuData, threadData) || comp->fmuData->simulationInfo.needToIterate || checkRelations(comp->fmuData) || eventInfo->stateValuesChanged)
+    if(comp->fmuData->callback->checkForDiscreteChanges(comp->fmuData, threadData) || comp->fmuData->simulationInfo->needToIterate || checkRelations(comp->fmuData) || eventInfo->stateValuesChanged)
     {
       intermediateResults = fmiTrue;
       if (comp->loggingOn)
@@ -834,8 +838,12 @@ fmiStatus fmiTerminate(fmiComponent c)
   /* free stateset data */
   freeStateSetData(comp->fmuData);
   deInitializeDataStruc(comp->fmuData);
+  /* free simuation data */
+  comp->functions.freeMemory(comp->fmuData->modelData);
+  comp->functions.freeMemory(comp->fmuData->simulationInfo);
+
   comp->functions.freeMemory(comp->threadData);
-  GC_free(comp->fmuData);
+  comp->functions.freeMemory(comp->fmuData);
 
   comp->state = modelTerminated;
   return fmiOK;
