@@ -945,6 +945,7 @@ namespace IAEX
    */
   void CellDocument::mouseClickedOnCell(Cell *clickedCell)
   {
+
     // 2006-04-25, AF
     if( lastClickedCell_ == clickedCell )
       return;
@@ -976,10 +977,27 @@ namespace IAEX
       getCursor()->moveAfter(clickedCell); //Results in bus error why?
     }
 
+   if( typeid(LatexCell) == typeid(*clickedCell))
+    {
+     LatexCell *latexcell = dynamic_cast<LatexCell*>(clickedCell);
+     bool r =latexcell->isEvaluated();
+     if(r==true)
+     {
+       latexcell->input_->setReadOnly(true);
+       latexcell->setFocus(true);
+     }
+     else
+     {
+       latexcell->input_->setReadOnly(false);
+     }
+    }
+    else
+    {
     clickedCell->setReadOnly(false);
     clickedCell->setFocus(true);
-
+      }
     emit cursorChanged();
+
   }
 
   /*!
@@ -1026,6 +1044,21 @@ namespace IAEX
       graphcell->setFocusOutput(true);
     }
 
+    else if(typeid(LatexCell) == typeid(*clickedCell))
+    {
+      LatexCell *latexcell = dynamic_cast<LatexCell*>(clickedCell);
+      //latexcell->setReadOnly(false);
+      latexcell->setFocusOutput(true);
+      latexcell->output_->setReadOnly(false);
+     /* QString text=latexcell->textOutput();
+      if(!text.isEmpty())
+      {
+          latexcell->output_->hide();
+          latexcell->input_->show();
+          latexcell->hideButton->show();
+      } */
+    }
+
     else
     {
       clickedCell->setReadOnly(false);
